function [f] = iGEM_TUeindhoven_2012_basic_ode(t,x,par)

%State variables
CaM = x(1); %Concentration calcium-calmodulin combination (uM)
CaN = x(2); %Concentration calcium-calcineurin combination (uM)
Crz = x(3); %Crz concentration (uM)
Ca = x(4); %Cystolic calcium concentration (uM)

%Basic variables
Ca_ex = par(1); %Extracellular calcium concentration (uM)

%Parameters of CaM
kmf = par(2); %Forward rate constant (uM-3 s-1)
kmb = par(3); %Backward rate constant (s-1)
CaMtot = par(4); %total calmodulin (bound + unbound)

%Parameters of CaN
knf = par(5); %Forward rate constant (uM-1 s-1)
knb = par(6); %Backward rate constant (s-1)
CaNtot = par(7); %total calcineurin (bound + unbound)

%Parameters of total nuclear fraction Crz1
khf = par(8); %import rate constant (s-1)
khb = par(9); %export rate constant (s-1)
nsites = par(10); %number of relevant regulatory phosporylation sites
lzero = par(11); %basic equilibrium constant
lamda = par(12); %increment factor

%Parameters Michaelis Menten
kx = par(13); %binding constant of Transporter X (uM)
k1 = par(14); %binding constant of Pmc1 (uM)
k2 = par(15); %binding constant of Pmr1 (uM)
k3 = par(16); %binding constant of Vcx1 (uM)
vx = par(17); %rate parameter of Transporter X (uM s-1)
v1 = par(18); %rate parameter of Pmc1 (uM s-1)
v2 = par(19); %rate parameter of Pmr1 (uM s-1)
v3 = par(20); %rate parameter of Vcx1 (uM s-1)
kc = par(21); %feedback control constant
alpha = par(22); %growth rate constant (s-1)

%Concentration calcium-calmodulin combination (uM)
f(1) = (kmf*(CaMtot-CaM)*Ca^3) - (kmb*CaM);
%Concentration calcium-calcineurin combination (uM)
f(2) = (knf*(CaNtot-CaN)*CaM) - (knb*CaN);
%Crz concentration (uM)
f(3) = khf*(1/(1 + ((lzero * ((lamda/CaN)^(nsites+1)-1)/((lamda/CaN)-1)...
    * ((CaN^-1 - 1)/(CaN^(-(nsites+1))-1))))))*(1-Crz)...
    - (khb*(1-((1/(1 + ((lzero * ((lamda/CaN)^(nsites+1)-1)/((lamda/CaN)-1)...
    * ((CaN^-1 - 1)/(CaN^(-(nsites+1))-1))))))))*Crz);
%Cystolic calcium concentration (uM)
f(4) = ((vx*Ca_ex)/(kx+Ca_ex))... %transporter X
    - (Crz * (1/(1 + (lzero *(((lamda/CaN)^(nsites+1)-1)/((lamda/CaN)-1))...
    * (((CaN^-1) - 1)/(CaN^(-(nsites+1))-1))))) * ...
    ((v1*Ca)/(k1+Ca)))...         %Pmc1
    - (Crz * (1/(1 + (lzero *(((lamda/CaN)^(nsites+1)-1)/((lamda/CaN)-1))...
    * (((CaN^-1) - 1)/(CaN^(-(nsites+1))-1))))) * ...
    ((v2*Ca)/(k2+Ca)))...         %Pmr1
    - ((1.0 / (1.0+kc*CaN)) * ((v3*Ca)/(k3+Ca)))... %Vcx1
    - (alpha * Ca);

f = f(:);