function [f] = iGEM_TUeindhoven_2012_total_ode(t,x,par)

%State variables
CaM = x(1); %Concentration calcium-calmodulin combination (uM)
CaN = x(2); %Concentration calcium-calcineurin combination (uM)
CaGeco = x(3); %Concentration calcium-GECO combination (uM)
Crz = x(4); %Crz concentration (uM)
Ca = x(5); %Cystolic calcium concentration (uM)
m = x(6); %Hypothetical activation variable (mV)

%Voltage pulse (mV)
if (t>3 && t<=4)||(t>7 && t<=8)||(t>11 && t <=12)||(t>15 && t<=16)
    V = 32;
else
    V=-50;
end

%Parameters of ionic current flow
i = par(1); %Integral power of hypothetical activation variable
j = par(2); %Integral power of hypothetical inactivation variable
g = par(3); %Membrane conductance (s)
K = par(4); %Halfway inactivation concentration (uM)
Vn = par(5); %Volume of the cell (L)
Ca_ex = par(6); %Extracellular calcium concentration (uM)
F = 9.649e10; %Faraday's constant (Coulomb uM^{-1})

m_inf = 1/(1 + exp(-(V-3)/8)); %Steady state value of hypothetical activation variable (mV)
tau_m = 7.8/(exp((V-3)/8) + exp(-(V-3)/8)); %Time constant (mV^{-1})
%%% h = K/(K+Ca); %Hypothetical inactivation variable (uM)
%%% E = 12.5*log(Ca_ex/Ca); %Reversal potential (mV)

%Parameters of CaM
kmf = par(7); %Forward rate constant (uM-3 s-1)
kmb = par(8); %Backward rate constant (s-1)
CaMtot = par(9); %total calmodulin (bound + unbound)

%Parameters of CaN
knf = par(10); %Forward rate constant (uM-1 s-1)
knb = par(11); %Backward rate constant (s-1)
CaNtot = par(12); %total calcineurin (bound + unbound)

%Parameters of total nuclear fraction Crz1
khf = par(13); %import rate constant (s-1)
khb = par(14); %export rate constant (s-1)
nsites = par(15); %number of relevant regulatory phosporylation sites
lzero = par(16); %basic equilibrium constant
lamda = par(17); %increment factor

%Parameters Michaelis Menten
kx = par(18); %binding constant of Transporter X (uM)
k1 = par(19); %binding constant of Pmc1 (uM)
k2 = par(20); %binding constant of Pmr1 (uM)
k3 = par(21); %binding constant of Vcx1 (uM)
vx = par(22); %rate parameter of Transporter X (uM s-1)
v1 = par(23); %rate parameter of Pmc1 (uM s-1)
v2 = par(24); %rate parameter of Pmr1 (uM s-1)
v3 = par(25); %rate parameter of Vcx1 (uM s-1)
kc = par(26); %feedback control constant
alpha = par(27); %growth rate constant (s-1)

%Parameters Geco kinetics
nhill = par(28); %number of binding calcium
kgf = par(29); %forward rate constant
kgb = par(30); %backward rate constant
Gectot = par(31); %total GECO (bound + unbound)


%Concentration calcium-calmodulin combination (uM)
f(1) = (kmf*(CaMtot-CaM)*Ca^3) - (kmb*CaM);
%Concentration calcium-calcineurin combination (uM)
f(2) = (knf*(CaNtot-CaN)*CaM) - (knb*CaN);
%Concentration calcium-GECO combination (uM)
f(3) = (kgf*(Gectot-CaGeco)*((Ca*10^-6)^nhill)) - (kgb*CaGeco);
%Crz concentration (uM)
f(4) = khf*(1/(1 + ((lzero * ((lamda/CaN)^(nsites+1)-1)/((lamda/CaN)-1)...
    * ((CaN^-1 - 1)/(CaN^(-(nsites+1))-1))))))*(1-Crz)...
    - (khb*(1-((1/(1 + ((lzero * ((lamda/CaN)^(nsites+1)-1)/((lamda/CaN)-1)...
    * ((CaN^-1 - 1)/(CaN^(-(nsites+1))-1))))))))*Crz);
%Cystolic calcium concentration (uM)
f(5) = ((vx*Ca_ex)/(kx+Ca_ex))... %transporter X
    - (Crz * (1/(1 + (lzero *(((lamda/CaN)^(nsites+1)-1)/((lamda/CaN)-1))...
    * (((CaN^-1) - 1)/(CaN^(-(nsites+1))-1))))) * ...
    ((v1*Ca)/(k1+Ca)))...         %Pmc1
    - (Crz * (1/(1 + (lzero *(((lamda/CaN)^(nsites+1)-1)/((lamda/CaN)-1))...
    * (((CaN^-1) - 1)/(CaN^(-(nsites+1))-1))))) * ...
    ((v2*Ca)/(k2+Ca)))...         %Pmr1
    - ((1.0 / (1.0+kc*CaN)) * ((v3*Ca)/(k3+Ca)))... %Vcx1
    - (alpha * Ca)...
    - (-g*m^(i)*(K/(K+Ca))^(j)*(V - (12.5*log(Ca_ex/Ca))))/(2*F*Vn)...
    + nhill * ((kgb * CaGeco) - (kgf * (Ca*10^-6)^nhill * (Gectot - CaGeco)));
%Hypothetical activation variable (mV)
f(6) = ((m_inf - m)/(tau_m)); %m

f = f(:);